from cpl_core.application import StartupABC
from cpl_core.configuration import ConfigurationABC
from cpl_core.dependency_injection import ServiceProviderABC, ServiceCollectionABC
from cpl_core.environment import ApplicationEnvironment

from gismo_core.abc.bot_service_abc import BotServiceABC
from gismo_core.services.bot_service import BotService


class Startup(StartupABC):

    def __init__(self):
        StartupABC.__init__(self)

    async def configure_configuration(self, configuration: ConfigurationABC, environment: ApplicationEnvironment) -> ConfigurationABC:
        configuration.add_environment_variables('GISMO_')
        configuration.add_console_arguments()
        configuration.add_json_file(f'appsettings.json', optional=False)
        configuration.add_json_file(f'appsettings.{environment.environment_name}.json', optional=True)
        configuration.add_json_file(f'appsettings.{environment.host_name}.json', optional=True)
        
        return configuration

    async def configure_services(self, services: ServiceCollectionABC, environment: ApplicationEnvironment) -> ServiceProviderABC:
        services.add_logging()
        
        services.add_singleton(BotServiceABC, BotService)
        
        return services.build_service_provider()
